`timescale 1 ps / 1 ps
module pcie_a10_8x (
		input  wire         npor,               //               npor.npor
		input  wire         pin_perst,          //                   .pin_perst
		input  wire [4:0]   hpg_ctrler,         //          config_tl.hpg_ctrler
		output wire [3:0]   tl_cfg_add,         //                   .tl_cfg_add
		output wire [31:0]  tl_cfg_ctl,         //                   .tl_cfg_ctl
		output wire [52:0]  tl_cfg_sts,         //                   .tl_cfg_sts
		input  wire [6:0]   cpl_err,            //                   .cpl_err
		input  wire         cpl_pending,        //                   .cpl_pending
		input  wire         pm_auxpwr,          //         power_mngt.pm_auxpwr
		input  wire [9:0]   pm_data,            //                   .pm_data
		input  wire         pme_to_cr,          //                   .pme_to_cr
		input  wire         pm_event,           //                   .pm_event
		output wire         pme_to_sr,          //                   .pme_to_sr
		output wire [1:0]   currentspeed,       //         hip_status.currentspeed
		output wire         derr_cor_ext_rcv,   //                   .derr_cor_ext_rcv
		output wire         derr_cor_ext_rpl,   //                   .derr_cor_ext_rpl
		output wire         derr_rpl,           //                   .derr_rpl
		output wire         dlup,               //                   .dlup
		output wire         dlup_exit,          //                   .dlup_exit
		output wire         ev128ns,            //                   .ev128ns
		output wire         ev1us,              //                   .ev1us
		output wire         hotrst_exit,        //                   .hotrst_exit
		output wire [3:0]   int_status,         //                   .int_status
		output wire         l2_exit,            //                   .l2_exit
		output wire [3:0]   lane_act,           //                   .lane_act
		output wire [4:0]   ltssmstate,         //                   .ltssmstate
		output wire         rx_par_err,         //                   .rx_par_err
		output wire [1:0]   tx_par_err,         //                   .tx_par_err
		output wire         cfg_par_err,        //                   .cfg_par_err
		output wire [0:0]   rx_st_sop,          //              rx_st.startofpacket
		output wire [0:0]   rx_st_eop,          //                   .endofpacket
		output wire [0:0]   rx_st_err,          //                   .error
		output wire [0:0]   rx_st_valid,        //                   .valid
		input  wire         rx_st_ready,        //                   .ready
		output wire [63:0]  rx_st_data,         //                   .data
		output wire [7:0]   rx_st_bar,          //          rx_bar_be.rx_st_bar
		input  wire         rx_st_mask,         //                   .rx_st_mask
		input  wire [0:0]   tx_st_sop,          //              tx_st.startofpacket
		input  wire [0:0]   tx_st_eop,          //                   .endofpacket
		input  wire [0:0]   tx_st_err,          //                   .error
		input  wire [0:0]   tx_st_valid,        //                   .valid
		output wire         tx_st_ready,        //                   .ready
		input  wire [63:0]  tx_st_data,         //                   .data
		input  wire         pld_clk,            //            pld_clk.clk
		output wire         coreclkout_hip,     //     coreclkout_hip.clk
		input  wire         refclk,             //             refclk.clk
		output wire         reset_status,       //            hip_rst.reset_status
		output wire         serdes_pll_locked,  //                   .serdes_pll_locked
		output wire         pld_clk_inuse,      //                   .pld_clk_inuse
		input  wire         pld_core_ready,     //                   .pld_core_ready
		output wire         testin_zero,        //                   .testin_zero
		input  wire [7:0]   rx_in,
		output wire [7:0]   tx_out,
		input  wire         app_int_sts,        //            int_msi.app_int_sts
		input  wire [4:0]   app_msi_num,        //                   .app_msi_num
		input  wire         app_msi_req,        //                   .app_msi_req
		input  wire [2:0]   app_msi_tc,         //                   .app_msi_tc
		output wire         app_int_ack,        //                   .app_int_ack
		output wire         app_msi_ack,        //                   .app_msi_ack
		output wire [7:0]  ko_cpl_spc_header,   //               .ko_cpl_spc_header
		output wire [11:0] ko_cpl_spc_data,     //               .ko_cpl_spc_data
		input  wire [31:0]  test_in,            //           hip_ctrl.test_in
		input  wire         simu_mode_pipe      //                   .simu_mode_pipe
	);

	pcie_reconfig pcie_reconfig
	  (
		.test_in                 (test_in),                 //       hip_ctrl.test_in
		.simu_mode_pipe          (simu_mode_pipe),          //               .simu_mode_pipe
		.rx_in0                (rx_in[0]),                //     hip_serial.rx_in0
		.rx_in1                (rx_in[1]),                //               .rx_in1
		.rx_in2                (rx_in[2]),                //               .rx_in2
		.rx_in3                (rx_in[3]),                //               .rx_in3
		.rx_in4                (rx_in[4]),                //     hip_serial.rx_in0
		.rx_in5                (rx_in[5]),                //               .rx_in1
		.rx_in6                (rx_in[6]),                //               .rx_in2
		.rx_in7                (rx_in[7]),                //               .rx_in3
		.tx_out0               (tx_out[0]),               //               .tx_out0
		.tx_out1               (tx_out[1]),               //               .tx_out1
		.tx_out2               (tx_out[2]),               //               .tx_out2
		.tx_out3               (tx_out[3]),               //               .tx_out3
		.tx_out4               (tx_out[4]),               //               .tx_out0
		.tx_out5               (tx_out[5]),               //               .tx_out1
		.tx_out6               (tx_out[6]),               //               .tx_out2
		.tx_out7               (tx_out[7]),               //               .tx_out3
		.npor                        (npor),                        //           npor.npor
		.pin_perst                   (pin_perst),                   //               .pin_perst
		.refclk                       (refclk),                       //         refclk.clk
		.hpg_ctrler             (hpg_ctrler),             //      config_tl.hpg_ctrler
		.tl_cfg_add             (tl_cfg_add),             //               .tl_cfg_add
		.tl_cfg_ctl             (tl_cfg_ctl),             //               .tl_cfg_ctl
		.tl_cfg_sts             (tl_cfg_sts),             //               .tl_cfg_sts
		.cpl_err                (cpl_err),                //               .cpl_err
		.cpl_pending            (cpl_pending),            //               .cpl_pending
		.pm_auxpwr             (pm_auxpwr),             //     power_mngt.pm_auxpwr
		.pm_data               (pm_data),               //               .pm_data
		.pme_to_cr             (pme_to_cr),             //               .pme_to_cr
		.pm_event              (pm_event),              //               .pm_event
		.pme_to_sr             (pme_to_sr),             //               .pme_to_sr
		.rx_st_sop              (rx_st_sop),              //          rx_st.startofpacket
		.rx_st_eop                (rx_st_eop),                //               .endofpacket
		.rx_st_err                        (rx_st_err),                      //               .error
		.rx_st_valid                      (rx_st_valid),                      //               .valid
		.rx_st_ready                      (rx_st_ready),                      //               .ready
		.rx_st_data                       (rx_st_data),                       //               .data
		.rx_st_bar              (rx_st_bar),              //      rx_bar_be.rx_st_bar
		.rx_st_mask             (rx_st_mask),             //               .rx_st_mask
		.tx_st_sop                        (tx_st_sop),              //          tx_st.startofpacket
		.tx_st_eop                (tx_st_eop),                //               .endofpacket
		.tx_st_err                        (tx_st_err),                      //               .error
		.tx_st_valid                      (tx_st_valid),                      //               .valid
		.tx_st_ready                      (tx_st_ready),                      //               .ready
		.tx_st_data                       (tx_st_data),                       //               .data
		.app_int_sts              (app_int_sts),              //        int_msi.app_int_sts
		.app_msi_num              (app_msi_num),              //               .app_msi_num
		.app_msi_req              (app_msi_req),              //               .app_msi_req
		.app_msi_tc               (app_msi_tc),               //               .app_msi_tc
		.app_int_ack              (app_int_ack),              //               .app_int_ack
		.app_msi_ack              (app_msi_ack),               //               .app_msi_ack
		.tx_cred_fc_sel           (2'd0),
		.pld_clk                      (pld_clk),                      //        pld_clk.clk
		.coreclkout_hip               (coreclkout_hip),               // coreclkout_hip.clk
	        .currentspeed(currentspeed),
		.reset_status             (reset_status),             //        hip_rst.reset_status
		.serdes_pll_locked        (serdes_pll_locked),        //               .serdes_pll_locked
		.pld_clk_inuse            (pld_clk_inuse),            //               .pld_clk_inuse
		.pld_core_ready           (pld_core_ready),           //               .pld_core_ready
		.testin_zero              (testin_zero),              //               .testin_zero
		.derr_cor_ext_rcv  (derr_cor_ext_rcv),  // drv.derr_cor_ext_rcv
		.derr_cor_ext_rpl  (derr_cor_ext_rpl),  //               .derr_cor_ext_rpl
		.derr_rpl          (derr_rpl),          //               .derr_rpl
		.dlup_exit         (dlup_exit),         //               .dlup_exit
		.ev128ns           (ev128ns),           //               .ev128ns
		.ev1us             (ev1us),             //               .ev1us
		.hotrst_exit       (hotrst_exit),       //               .hotrst_exit
		.int_status        (int_status),        //               .int_status
		.l2_exit           (l2_exit),           //               .l2_exit
		.lane_act          (lane_act),          //               .lane_act
		.ltssmstate        (ltssmstate),        //               .ltssmstate
		.dlup              (dlup),              //               .dlup
		.rx_par_err        (rx_par_err),        //               .rx_par_err
		.tx_par_err        (tx_par_err),        //               .tx_par_err
		.cfg_par_err       (cfg_par_err),       //               .cfg_par_err
		.ko_cpl_spc_header (ko_cpl_spc_header), //               .ko_cpl_spc_header
		.ko_cpl_spc_data   (ko_cpl_spc_data)    //               .ko_cpl_spc_data
	);
endmodule
